@@ -1,25 +1,25 @@
 #' @title
-#' Create \code{microtable} object to store and manage all the basic files.
+#' Create \code{microtable} object to store and manage all the basic data.
 #'
 #' @description
-#' This class is a wrapper for a series of operations on the basic data manipulations,
+#' This class is a wrapper for a series of manipulations on the basic data,
 #' including microtable object creation, data trimming, data filtering, rarefaction based on Paul et al. (2013) <doi:10.1371/journal.pone.0061217>, taxonomic abundance calculation, 
 #' alpha and beta diversity calculation based on the An et al. (2019) <doi:10.1016/j.geoderma.2018.09.035> and 
-#' Lozupone et al. (2005) <doi:10.1128/AEM.71.12.8228-8235.2005> and other basic operations.\cr
-#' \cr
+#' Lozupone et al. (2005) <doi:10.1128/AEM.71.12.8228-8235.2005> and other basic operations.
+#' 
 #' Online tutorial: \href{https://chiliubio.github.io/microeco_tutorial/}{https://chiliubio.github.io/microeco_tutorial/} \cr
 #' Download tutorial: \href{https://github.com/ChiLiubio/microeco_tutorial/releases}{https://github.com/ChiLiubio/microeco_tutorial/releases}
 #' 
 #' @export
 microtable <- R6Class(classname = "microtable",
 	public = list(
-		#' @param otu_table data.frame class; Feature abundance table; rownames are features (e.g. OTUs/ASVs/species/genes); column names are samples.
-		#' @param sample_table default NULL; data.frame; The sample information table; rownames are samples; columns are sample metadata; 
-		#' 	 If not provided, the function can generate a table automatically according to the sample names in \code{otu_table}.
-		#' @param tax_table default NULL; data.frame class; Taxonomic information table; rownames are features; column names are taxonomic ranks.
+		#' @param otu_table data.frame class; Feature abundance table; row names must be feature (e.g. OTUs/ASVs/species/genes) names; column names are sample names.
+		#' @param sample_table default NULL; data.frame class; Sample information table (optional); row names should be sample names; columns are sample metadata; 
+		#' 	 If not provided, the function can generate a table automatically according to the sample names in the input \code{otu_table}.
+		#' @param tax_table default NULL; data.frame class; Taxonomic information table (optional); row names are feature names; column names are taxonomic ranks.
 		#' 	 This can also be other hierarchical information tables, such as traits, genes, or metabolic pathways.
-		#' @param phylo_tree default NULL; phylo class; Phylogenetic tree; It must be read with the \code{read.tree} function of ape package.
-		#' @param rep_fasta default NULL; \code{DNAStringSet}, \code{list} or \code{DNAbin} class; Representative sequences of OTUs/ASVs.
+		#' @param phylo_tree default NULL; phylo class; Phylogenetic tree (optional); It must be read with the \code{read.tree} function of ape package.
+		#' @param rep_fasta default NULL; \code{DNAStringSet}, \code{list} or \code{DNAbin} class; Representative sequences of OTUs/ASVs (optional).
 		#'   The sequences should be read with the \code{readDNAStringSet} function of \code{Biostrings} package (DNAStringSet class), 
 		#'   \code{read.fasta} function of \code{seqinr} package (list class),
 		#'   or \code{read.FASTA} function of \code{ape} package (DNAbin class).
@@ -27,11 +27,11 @@ microtable <- R6Class(classname = "microtable",
 		#'   If TRUE, the function can invoke the \code{tidy_dataset} function.
 		#' @return an object of \code{microtable} class with the following components:
 		#' \describe{
-		#'   \item{\code{sample_table}}{The sample information table.}
-		#'   \item{\code{otu_table}}{The feature table.}
-		#'   \item{\code{tax_table}}{The taxonomic table.}
-		#'   \item{\code{phylo_tree}}{The phylogenetic tree.}
-		#'   \item{\code{rep_fasta}}{The sequences.}
+		#'   \item{\code{sample_table}}{Sample information table.}
+		#'   \item{\code{otu_table}}{Feature table.}
+		#'   \item{\code{tax_table}}{Taxonomic table (when provided).}
+		#'   \item{\code{phylo_tree}}{Phylogenetic tree (when provided).}
+		#'   \item{\code{rep_fasta}}{Sequences (when provided).}
 		#'   \item{\code{taxa_abund}}{default NULL; use \code{cal_abund} function to calculate.}
 		#'   \item{\code{alpha_diversity}}{default NULL; use \code{cal_alphadiv} function to calculate.}
 		#'   \item{\code{beta_diversity}}{default NULL; use \code{cal_betadiv} function to calculate.}
@@ -95,11 +95,11 @@ microtable <- R6Class(classname = "microtable",
 		},
 		#' @description
 		#' Filter the features considered pollution in \code{microtable$tax_table}.
-		#' This operation will remove any line of the \code{microtable$tax_table} containing any the word in taxa parameter regardless of word case.
+		#' This operation will remove any line of \code{microtable$tax_table} containing any the word in input \code{taxa} parameter regardless of word case.
 		#'
 		#' @param taxa default \code{c("mitochondria", "chloroplast")}; filter mitochondria and chloroplast, or others as needed.
 		#' @return updated microtable object
-		#' @examples 
+		#' @examples
 		#' m1$filter_pollution(taxa = c("mitochondria", "chloroplast"))
 		filter_pollution = function(taxa = c("mitochondria", "chloroplast")){
 			if(is.null(self$tax_table)){
@@ -303,9 +303,9 @@ microtable <- R6Class(classname = "microtable",
 		#' @return tax_table updated in the object.
 		#' @examples
 		#' \donttest{
-		#' m1$add_rownames2taxonomy()
+		#' m1$add_rownames2tax()
 		#' }
-		add_rownames2taxonomy = function(use_name = "OTU"){
+		add_rownames2tax = function(use_name = "OTU"){
 			self$tidy_dataset()
 			if(is.null(self$tax_table)){
 				message("The tax_table in the microtable object is NULL! Create one ...")
@@ -878,6 +878,14 @@ microtable <- R6Class(classname = "microtable",
 			if(!is.null(self$alpha_diversity)) cat(paste("Alpha diversity: calculated for", paste0(colnames(self$alpha_diversity), collapse = ","), "\n"))
 			if(!is.null(self$beta_diversity)) cat(paste("Beta diversity: calculated for", paste0(names(self$beta_diversity), collapse = ","), "\n"))
 			invisible(self)
+		},
+		#' @description
+		#' This is a deprecated function. Please use \code{add_rownames2tax} function instead.
+		#'
+		#' @param ... paremeters pass to \code{add_rownames2tax}.
+		add_rownames2taxonomy = function(...){
+			lifecycle::deprecate_warn("2.0.0", "add_rownames2taxonomy()", "add_rownames2tax()")
+			self$add_rownames2tax(...)
 		}
 	),
 	private = list(
@@ -888,7 +896,7 @@ microtable <- R6Class(classname = "microtable",
 		},
 		check_tbldf = function(input_table, showname){
 			if(inherits(input_table, "tbl_df")){
-				stop("Input ", showname, " is tbl_df format! It may be created using tibble package! Please convert it to traditional data.frame class!")
+				stop("Input ", showname, " is tbl_df format! It may be created using tibble package! Please convert it to basic data.frame class!")
 			}
 		},
 		check_colnames = function(input_table, showname){
